Contributing to MPDAF
=====================

Reporting Issues
----------------

When opening an issue to report a problem, please try to provide a minimal
code example that reproduces the issue, and also include details of the
operating system, and the Python, Numpy, Astropy and MPDAF versions you are 
using.

Contributing code
-----------------

If you're interested in contributing code to MPDAF, please have a look at the 
[dedicated documentation](http://mpdaf.readthedocs.io/en/latest/contribute.html).